@@ -1,28 +1,50 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 /****************************************************************************
 ** Meta object code from reading C++ file 'FigureWindow.h'
 **
-** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
+** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/e/cyg_pub/devel/octave/octave-4.0.1-1.x86_64/src/octave-4.0.1/libgui/graphics/FigureWindow.h"
+#include "/cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.i686/src/octave-4.4.1/libgui/graphics/FigureWindow.h"
+#include <QtCore/qbytearray.h>
+#include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'FigureWindow.h' doesn't include <QObject>."
-#elif Q_MOC_OUTPUT_REVISION != 63
-#error "This file was generated using the moc from 4.8.7. It"
+#elif Q_MOC_OUTPUT_REVISION != 67
+#error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
 QT_BEGIN_MOC_NAMESPACE
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+struct qt_meta_stringdata_QtHandles__FigureWindow_t {
+    QByteArrayData data[1];
+    char stringdata0[24];
+};
+#define QT_MOC_LITERAL(idx, ofs, len) \
+    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
+    qptrdiff(offsetof(qt_meta_stringdata_QtHandles__FigureWindow_t, stringdata0) + ofs \
+        - idx * sizeof(QByteArrayData)) \
+    )
+static const qt_meta_stringdata_QtHandles__FigureWindow_t qt_meta_stringdata_QtHandles__FigureWindow = {
+    {
+QT_MOC_LITERAL(0, 0, 23) // "QtHandles::FigureWindow"
+
+    },
+    "QtHandles::FigureWindow"
+};
+#undef QT_MOC_LITERAL
+
 static const uint qt_meta_data_QtHandles__FigureWindow[] = {
 
  // content:
-       6,       // revision
+       7,       // revision
        0,       // classname
        0,    0, // classinfo
        0,    0, // methods
@@ -35,10 +57,6 @@ static const uint qt_meta_data_QtHandles__FigureWindow[] = {
        0        // eod
 };
 
-static const char qt_meta_stringdata_QtHandles__FigureWindow[] = {
-    "QtHandles::FigureWindow\0"
-};
-
 void QtHandles::FigureWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
     Q_UNUSED(_o);
@@ -47,37 +65,29 @@ void QtHandles::FigureWindow::qt_static_metacall(QObject *_o, QMetaObject::Call
     Q_UNUSED(_a);
 }
 
-const QMetaObjectExtraData QtHandles::FigureWindow::staticMetaObjectExtraData = {
-    0,  qt_static_metacall 
-};
-
 const QMetaObject QtHandles::FigureWindow::staticMetaObject = {
-    { &FigureWindowBase::staticMetaObject, qt_meta_stringdata_QtHandles__FigureWindow,
-      qt_meta_data_QtHandles__FigureWindow, &staticMetaObjectExtraData }
+    { &FigureWindowBase::staticMetaObject, qt_meta_stringdata_QtHandles__FigureWindow.data,
+      qt_meta_data_QtHandles__FigureWindow,  qt_static_metacall, nullptr, nullptr}
 };
 
-#ifdef Q_NO_DATA_RELOCATION
-const QMetaObject &QtHandles::FigureWindow::getStaticMetaObject() { return staticMetaObject; }
-#endif //Q_NO_DATA_RELOCATION
 
 const QMetaObject *QtHandles::FigureWindow::metaObject() const
 {
-    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
+    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
 }
 
 void *QtHandles::FigureWindow::qt_metacast(const char *_clname)
 {
-    if (!_clname) return 0;
-    if (!strcmp(_clname, qt_meta_stringdata_QtHandles__FigureWindow))
-        return static_cast<void*>(const_cast< FigureWindow*>(this));
+    if (!_clname) return nullptr;
+    if (!strcmp(_clname, qt_meta_stringdata_QtHandles__FigureWindow.stringdata0))
+        return static_cast<void*>(this);
     return FigureWindowBase::qt_metacast(_clname);
 }
 
 int QtHandles::FigureWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
 {
     _id = FigureWindowBase::qt_metacall(_c, _id, _a);
-    if (_id < 0)
-        return _id;
     return _id;
 }
+QT_WARNING_POP
 QT_END_MOC_NAMESPACE
