@@ -1,28 +1,54 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 /****************************************************************************
 ** Meta object code from reading C++ file 'ToggleTool.h'
 **
-** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
+** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/e/cyg_pub/devel/octave/octave-4.0.1-1.i686/src/octave-4.0.1/libgui/graphics/ToggleTool.h"
+#include "/cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.x86_64/src/octave-4.4.1/libgui/graphics/ToggleTool.h"
+#include <QtCore/qbytearray.h>
+#include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'ToggleTool.h' doesn't include <QObject>."
-#elif Q_MOC_OUTPUT_REVISION != 63
-#error "This file was generated using the moc from 4.8.7. It"
+#elif Q_MOC_OUTPUT_REVISION != 67
+#error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
 QT_BEGIN_MOC_NAMESPACE
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+struct qt_meta_stringdata_QtHandles__ToggleTool_t {
+    QByteArrayData data[4];
+    char stringdata0[41];
+};
+#define QT_MOC_LITERAL(idx, ofs, len) \
+    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
+    qptrdiff(offsetof(qt_meta_stringdata_QtHandles__ToggleTool_t, stringdata0) + ofs \
+        - idx * sizeof(QByteArrayData)) \
+    )
+static const qt_meta_stringdata_QtHandles__ToggleTool_t qt_meta_stringdata_QtHandles__ToggleTool = {
+    {
+QT_MOC_LITERAL(0, 0, 21), // "QtHandles::ToggleTool"
+QT_MOC_LITERAL(1, 22, 9), // "triggered"
+QT_MOC_LITERAL(2, 32, 0), // ""
+QT_MOC_LITERAL(3, 33, 7) // "checked"
+
+    },
+    "QtHandles::ToggleTool\0triggered\0\0"
+    "checked"
+};
+#undef QT_MOC_LITERAL
+
 static const uint qt_meta_data_QtHandles__ToggleTool[] = {
 
  // content:
-       6,       // revision
+       7,       // revision
        0,       // classname
        0,    0, // classinfo
        1,   14, // methods
@@ -32,22 +58,20 @@ static const uint qt_meta_data_QtHandles__ToggleTool[] = {
        0,       // flags
        0,       // signalCount
 
- // slots: signature, parameters, type, tag, flags
-      31,   23,   22,   22, 0x08,
+ // slots: name, argc, parameters, tag, flags
+       1,    1,   19,    2, 0x08 /* Private */,
+
+ // slots: parameters
+    QMetaType::Void, QMetaType::Bool,    3,
 
        0        // eod
 };
 
-static const char qt_meta_stringdata_QtHandles__ToggleTool[] = {
-    "QtHandles::ToggleTool\0\0checked\0"
-    "triggered(bool)\0"
-};
-
 void QtHandles::ToggleTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
     if (_c == QMetaObject::InvokeMetaMethod) {
-        Q_ASSERT(staticMetaObject.cast(_o));
         ToggleTool *_t = static_cast<ToggleTool *>(_o);
+        Q_UNUSED(_t)
         switch (_id) {
         case 0: _t->triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
         default: ;
@@ -55,29 +79,22 @@ void QtHandles::ToggleTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c
     }
 }
 
-const QMetaObjectExtraData QtHandles::ToggleTool::staticMetaObjectExtraData = {
-    0,  qt_static_metacall 
-};
-
 const QMetaObject QtHandles::ToggleTool::staticMetaObject = {
-    { &ToolBarButton<uitoggletool>::staticMetaObject, qt_meta_stringdata_QtHandles__ToggleTool,
-      qt_meta_data_QtHandles__ToggleTool, &staticMetaObjectExtraData }
+    { &ToolBarButton<uitoggletool>::staticMetaObject, qt_meta_stringdata_QtHandles__ToggleTool.data,
+      qt_meta_data_QtHandles__ToggleTool,  qt_static_metacall, nullptr, nullptr}
 };
 
-#ifdef Q_NO_DATA_RELOCATION
-const QMetaObject &QtHandles::ToggleTool::getStaticMetaObject() { return staticMetaObject; }
-#endif //Q_NO_DATA_RELOCATION
 
 const QMetaObject *QtHandles::ToggleTool::metaObject() const
 {
-    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
+    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
 }
 
 void *QtHandles::ToggleTool::qt_metacast(const char *_clname)
 {
-    if (!_clname) return 0;
-    if (!strcmp(_clname, qt_meta_stringdata_QtHandles__ToggleTool))
-        return static_cast<void*>(const_cast< ToggleTool*>(this));
+    if (!_clname) return nullptr;
+    if (!strcmp(_clname, qt_meta_stringdata_QtHandles__ToggleTool.stringdata0))
+        return static_cast<void*>(this);
     return ToolBarButton<uitoggletool>::qt_metacast(_clname);
 }
 
@@ -90,7 +107,12 @@ int QtHandles::ToggleTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
         if (_id < 1)
             qt_static_metacall(this, _c, _id, _a);
         _id -= 1;
+    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
+        if (_id < 1)
+            *reinterpret_cast<int*>(_a[0]) = -1;
+        _id -= 1;
     }
     return _id;
 }
+QT_WARNING_POP
 QT_END_MOC_NAMESPACE
