@@ -1,28 +1,52 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 /****************************************************************************
 ** Meta object code from reading C++ file 'ToolBar.h'
 **
-** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
+** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/e/cyg_pub/devel/octave/octave-4.0.1-1.i686/src/octave-4.0.1/libgui/graphics/ToolBar.h"
+#include "/cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.x86_64/src/octave-4.4.1/libgui/graphics/ToolBar.h"
+#include <QtCore/qbytearray.h>
+#include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'ToolBar.h' doesn't include <QObject>."
-#elif Q_MOC_OUTPUT_REVISION != 63
-#error "This file was generated using the moc from 4.8.7. It"
+#elif Q_MOC_OUTPUT_REVISION != 67
+#error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
 QT_BEGIN_MOC_NAMESPACE
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+struct qt_meta_stringdata_QtHandles__ToolBar_t {
+    QByteArrayData data[3];
+    char stringdata0[30];
+};
+#define QT_MOC_LITERAL(idx, ofs, len) \
+    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
+    qptrdiff(offsetof(qt_meta_stringdata_QtHandles__ToolBar_t, stringdata0) + ofs \
+        - idx * sizeof(QByteArrayData)) \
+    )
+static const qt_meta_stringdata_QtHandles__ToolBar_t qt_meta_stringdata_QtHandles__ToolBar = {
+    {
+QT_MOC_LITERAL(0, 0, 18), // "QtHandles::ToolBar"
+QT_MOC_LITERAL(1, 19, 9), // "hideEmpty"
+QT_MOC_LITERAL(2, 29, 0) // ""
+
+    },
+    "QtHandles::ToolBar\0hideEmpty\0"
+};
+#undef QT_MOC_LITERAL
+
 static const uint qt_meta_data_QtHandles__ToolBar[] = {
 
  // content:
-       6,       // revision
+       7,       // revision
        0,       // classname
        0,    0, // classinfo
        1,   14, // methods
@@ -32,21 +56,20 @@ static const uint qt_meta_data_QtHandles__ToolBar[] = {
        0,       // flags
        0,       // signalCount
 
- // slots: signature, parameters, type, tag, flags
-      20,   19,   19,   19, 0x08,
+ // slots: name, argc, parameters, tag, flags
+       1,    0,   19,    2, 0x08 /* Private */,
+
+ // slots: parameters
+    QMetaType::Void,
 
        0        // eod
 };
 
-static const char qt_meta_stringdata_QtHandles__ToolBar[] = {
-    "QtHandles::ToolBar\0\0hideEmpty()\0"
-};
-
 void QtHandles::ToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
     if (_c == QMetaObject::InvokeMetaMethod) {
-        Q_ASSERT(staticMetaObject.cast(_o));
         ToolBar *_t = static_cast<ToolBar *>(_o);
+        Q_UNUSED(_t)
         switch (_id) {
         case 0: _t->hideEmpty(); break;
         default: ;
@@ -55,29 +78,22 @@ void QtHandles::ToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, i
     Q_UNUSED(_a);
 }
 
-const QMetaObjectExtraData QtHandles::ToolBar::staticMetaObjectExtraData = {
-    0,  qt_static_metacall 
-};
-
 const QMetaObject QtHandles::ToolBar::staticMetaObject = {
-    { &Object::staticMetaObject, qt_meta_stringdata_QtHandles__ToolBar,
-      qt_meta_data_QtHandles__ToolBar, &staticMetaObjectExtraData }
+    { &Object::staticMetaObject, qt_meta_stringdata_QtHandles__ToolBar.data,
+      qt_meta_data_QtHandles__ToolBar,  qt_static_metacall, nullptr, nullptr}
 };
 
-#ifdef Q_NO_DATA_RELOCATION
-const QMetaObject &QtHandles::ToolBar::getStaticMetaObject() { return staticMetaObject; }
-#endif //Q_NO_DATA_RELOCATION
 
 const QMetaObject *QtHandles::ToolBar::metaObject() const
 {
-    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
+    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
 }
 
 void *QtHandles::ToolBar::qt_metacast(const char *_clname)
 {
-    if (!_clname) return 0;
-    if (!strcmp(_clname, qt_meta_stringdata_QtHandles__ToolBar))
-        return static_cast<void*>(const_cast< ToolBar*>(this));
+    if (!_clname) return nullptr;
+    if (!strcmp(_clname, qt_meta_stringdata_QtHandles__ToolBar.stringdata0))
+        return static_cast<void*>(this);
     return Object::qt_metacast(_clname);
 }
 
@@ -90,7 +106,12 @@ int QtHandles::ToolBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
         if (_id < 1)
             qt_static_metacall(this, _c, _id, _a);
         _id -= 1;
+    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
+        if (_id < 1)
+            *reinterpret_cast<int*>(_a[0]) = -1;
+        _id -= 1;
     }
     return _id;
 }
+QT_WARNING_POP
 QT_END_MOC_NAMESPACE
